ewa.rules._jsonable

Package ewa :: Module rules :: Class _jsonable |
[hide private]
[frames] | no frames]

# Class _jsonable

source code

    object --+
             |
            _jsonable

Known Subclasses:
  - And
  - , CurrentTimeMatch
  - , DefaultRule
  - , FileTimeMatch
  - , GlobMatcher
  - , MatchRule
  - , Not
  - , Or
  - , RegexMatcher
  - , RuleList

Instance Methods | [hide private]
to_jsondata(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`